from unittest.mock import patch

from discordproxy.client import DiscordClient

from django.test import TestCase

from mailrelay.providers import create_discordproxy_client


@patch("mailrelay.providers.DISCORDPROXY_HOST", "1.2.3.4")
@patch("mailrelay.providers.DISCORDPROXY_PORT", "56789")
@patch("mailrelay.providers.MAILRELAY_DISCORDPROXY_TIMEOUT", 42)
class TestCreateDiscordproxyClient(TestCase):
    def test_should_return_client(self):
        r = create_discordproxy_client()
        self.assertIsInstance(r, DiscordClient)
        self.assertEqual(r.target, "1.2.3.4:56789")
        self.assertEqual(r.timeout, 42)



"""Settings for Mail Relay."""

from app_utils.app_settings import clean_setting

DISCORDPROXY_HOST = clean_setting("DISCORDPROXY_HOST", "localhost")
"""Port used to communicate with Discord Proxy."""

DISCORDPROXY_PORT = clean_setting("DISCORDPROXY_PORT", 50051)
"""Host used to communicate with Discord Proxy."""

MAILRELAY_DISCORDPROXY_TIMEOUT = clean_setting("MAILRELAY_DISCORDPROXY_TIMEOUT", 30)
"""Timeout for sending request to DISCORDPROXY in seconds."""

MAILRELAY_OLDEST_MAIL_HOURS = clean_setting("MAILRELAY_OLDEST_MAIL_HOURS", 2)
"""Oldest mail to be forwarded in hours. Set to 0 to disable."""

MAILRELAY_RELAY_GRACE_MINUTES = clean_setting("MAILRELAY_RELAY_GRACE_MINUTES", 30)
"""Max time in minutes since last successful relay before service is reported as down."""



"""Providers for Mail Relay."""

from discordproxy.client import DiscordClient

from .app_settings import (
    DISCORDPROXY_HOST,
    DISCORDPROXY_PORT,
    MAILRELAY_DISCORDPROXY_TIMEOUT,
)


def create_discordproxy_client() -> DiscordClient:
    """Return client from discordproxy configured for Mail Relay."""
    return DiscordClient(
        target=f"{DISCORDPROXY_HOST}:{DISCORDPROXY_PORT}",
        timeout=MAILRELAY_DISCORDPROXY_TIMEOUT,
    )
